import os
import threading
import inspect
from datetime import datetime

INFO = 'INFO'
WARNING = 'WARNING'
ERROR = 'ERROR'

def print_log(message, level=INFO):
    now = datetime.now()
    pid = os.getpid()
    current_thread = threading.current_thread()
    thread_info = f'{current_thread.getName()}-{current_thread.native_id}-{current_thread.ident}'

    # temporarily empty
    trace_id = ''

    callerframerecord = inspect.stack()[1]
    frame = callerframerecord[0]
    info = inspect.getframeinfo(frame)

    log_str = f'{now}|{trace_id}|{pid}|{thread_info}|{level}|{info.filename}-{info.lineno}|{str(message)}'
    print(log_str)



from distutils.core import setup
setup(
    name = 'print_logger',
    packages = ['print_logger'],
    version = '1.0.0',
    license='MIT',
    description = 'Python print with strict structure',
    author = 'Huan Nguyen',
    author_email = 'nguyenxuanhuan.95@gmail.com',
    url = 'https://github.com/xuanhuan95/print_log',
    # download_url = 'https://github.com/xuanhuan95/dist/print_log-00',
    keywords = ['PYTHON', 'PRINT', 'LOGGING'],   # Keywords that define your package best
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8', #Specify which python versions that you want to support
    ],
)